/*
 * Name:    v_xia_dxp.h
 *
 * Purpose: Header file for XIA DXP derived variables.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2001 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef _V_XIA_DXP_H_
#define _V_XIA_DXP_H_

#define MXU_XIA_DXP_VARIABLE_PARAMETER_LENGTH	80

#define MXT_XIA_DXP_VAR_PARAMETER		1
#define MXT_XIA_DXP_VAR_ROI_INTEGRAL		2
#define MXT_XIA_DXP_VAR_CORRECTED_ROI_INTEGRAL	3
#define MXT_XIA_DXP_VAR_REALTIME		4
#define MXT_XIA_DXP_VAR_LIVETIME		5
#define MXT_XIA_DXP_VAR_INPUT_COUNT_RATE	6
#define MXT_XIA_DXP_VAR_OUTPUT_COUNT_RATE	7
#define MXT_XIA_DXP_VAR_NUM_FAST_PEAKS		8
#define MXT_XIA_DXP_VAR_NUM_EVENTS		9
#define MXT_XIA_DXP_VAR_NUM_UNDERFLOWS		10
#define MXT_XIA_DXP_VAR_NUM_OVERFLOWS		11

typedef struct {
	MX_RECORD *mca_record;
	int value_type;
	char value_parameters[ MXU_XIA_DXP_VARIABLE_PARAMETER_LENGTH + 1 ];
} MX_XIA_DXP_VARIABLE;

#define MX_XIA_DXP_VARIABLE_STANDARD_FIELDS \
  {-1, -1, "mca_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_XIA_DXP_VARIABLE, mca_record), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY) }, \
  \
  {-1, -1, "value_type", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_XIA_DXP_VARIABLE, value_type), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY) }, \
  \
  {-1, -1, "value_parameters", MXFT_STRING, NULL, \
				1, {MXU_XIA_DXP_VARIABLE_PARAMETER_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_XIA_DXP_VARIABLE, value_parameters), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY) }

MX_API_PRIVATE mx_status_type mxv_xia_dxp_initialize_type( long );
MX_API_PRIVATE mx_status_type mxv_xia_dxp_create_record_structures(
							MX_RECORD *record );

MX_API_PRIVATE mx_status_type mxv_xia_dxp_finish_record_initialization(
							MX_RECORD *record );
MX_API_PRIVATE mx_status_type mxv_xia_dxp_delete_record(
							MX_RECORD *record );
MX_API_PRIVATE mx_status_type mxv_xia_dxp_dummy_function(
							MX_RECORD *record );

MX_API_PRIVATE mx_status_type mxv_xia_dxp_send_variable(
						MX_VARIABLE *variable );
MX_API_PRIVATE mx_status_type mxv_xia_dxp_receive_variable(
						MX_VARIABLE *variable );

extern MX_RECORD_FUNCTION_LIST mxv_xia_dxp_record_function_list;
extern MX_VARIABLE_FUNCTION_LIST mxv_xia_dxp_variable_function_list;

extern long mxv_xia_dxp_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxv_xia_dxp_rfield_def_ptr;

#endif /* _V_XIA_DXP_H_ */
